Configuring Relationships — SQLAlchemy 1.4 Documentation

Release: 1.4.21 | Release Date: July 14, 2021

# SQLAlchemy 1.4 Documentation

# Configuring Relationships

This section is covered by Defining Mapped Properties with Declarative.

## Evaluation of relationship arguments

This section is moved to Late-Evaluation of Relationship Arguments.

## Configuring Many-to-Many Relationships

This section is moved to Late-Evaluation for a many-to-many relationship.